<?php

namespace Restaurant\Website\Http\Controllers;

use App\Http\Controllers\APIController as BaseController;
use Restaurant\Website\Http\Requests\WebsiteRequest;
use Restaurant\Website\Interfaces\WebsiteRepositoryInterface;
use Restaurant\Website\Models\Website;
use Restaurant\Website\Forms\Website as Form;

/**
 * APIController  class for website.
 */
class WebsiteAPIController extends BaseController
{

    /**
     * Initialize website resource controller.
     *
     * @param type WebsiteRepositoryInterface $website
     *
     * @return null
     */
    public function __construct(WebsiteRepositoryInterface $website)
    {
        parent::__construct();
        $this->repository = $website;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Restaurant\Website\Repositories\Criteria\WebsiteResourceCriteria::class);
    }

    /**
     * Display a list of website.
     *
     * @return Response
     */
    public function index(WebsiteRequest $request)
    {
        return $this->repository
            ->setPresenter(\Restaurant\Website\Repositories\Presenter\WebsitePresenter::class)
            ->paginate();
    }

    /**
     * Display website.
     *
     * @param Request $request
     * @param Model   $website
     *
     * @return Response
     */
    public function show(WebsiteRequest $request, Website $website)
    {
        return $website->setPresenter(\Restaurant\Website\Repositories\Presenter\WebsiteListPresenter::class);
        ;
    }

    /**
     * Create new website.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(WebsiteRequest $request)
    {
        try {
            $data              = $request->all();
            $data['user_id']   = user_id();
            $data['user_type'] = user_type();
            $data              = $this->repository->create($data);
            $message           = trans('messages.success.created', ['Module' => trans('website::website.name')]);
            $code              = 204;
            $status            = 'success';
            $url               = guard_url('website/website/' . $website->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('website/website');
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Update the website.
     *
     * @param Request $request
     * @param Model   $website
     *
     * @return Response
     */
    public function update(WebsiteRequest $request, Website $website)
    {
        try {
            $data = $request->all();

            $website->update($data);
            $message = trans('messages.success.updated', ['Module' => trans('website::website.name')]);
            $code    = 204;
            $status  = 'success';
            $url     = guard_url('website/website/' . $website->getRouteKey());
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('website/website/' . $website->getRouteKey());
        }
        return compact('data', 'message', 'code', 'status', 'url');
    }

    /**
     * Remove the website.
     *
     * @param Model   $website
     *
     * @return Response
     */
    public function destroy(WebsiteRequest $request, Website $website)
    {
        try {
            $website->delete();
            $message = trans('messages.success.deleted', ['Module' => trans('website::website.name')]);
            $code    = 202;
            $status  = 'success';
            $url     = guard_url('website/website/0');
        } catch (Exception $e) {
            $message = $e->getMessage();
            $code    = 400;
            $status  = 'error';
            $url     = guard_url('website/website/' . $website->getRouteKey());
        }
        return compact('message', 'code', 'status', 'url');
    }

    /**
     * Return the form elements as json.
     *
     * @param String   $element
     *
     * @return json
     */
    public function form($element = 'fields')
    {
        $form = new Form();
        return $form->form($element, true);
    }

}
